lists.List (Partner List) — amici1

# `lists.List` (Partner List)

List(id, ref, designation, list_type, remarks, designation_de, designation_fr)

Master tables : lists.Lists (Partner Lists)

Slave tables : lists.MembersByList (Members)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Reference (ref) : The reference. This must be either empty or unique.

- Designation (designation) : See `<lino.utils.mldbc.fields.BabelCharField: designation>`.

- List Type (list_type) : See `<django.db.models.fields.related.ForeignKey: list_type>`.

- Remarks (remarks) : See `<django.db.models.fields.TextField: remarks>`.

- Designation (de) (designation_de) : See `<django.db.models.fields.CharField: designation_de>`.

- Designation (fr) (designation_fr) : See `<django.db.models.fields.CharField: designation_fr>`.

- Print (print_actions) : See `lino_xl.lib.lists.models.List.print_actions`.

- Name (name_column) : See `lino_xl.lib.lists.models.List.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.lists.models.List.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.lists.models.List.overview`.

Referenced from lists.Member.list

## Database fields

Internal name | Verbose name | Help text
id | ID |
ref | Reference | The reference. This must be either empty or unique.
designation | Designation |
list_type | List Type |
remarks | Remarks |
designation_de | Designation (de) |
designation_fr | Designation (fr) |
print_actions | Print |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |